==> liboggz_0.9.8.orig.tar.gz: liboggz-0.9.8/src/liboggz/oggz_dlist.h <==
/*
   Copyright (C) 2003 Commonwealth Scientific and Industrial Research
   Organisation (CSIRO) Australia

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   - Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

   - Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

   - Neither the name of CSIRO Australia nor the names of its
   contributors may be used to endorse or promote products derived from
   this software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
   PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE ORGANISATION OR
   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#ifndef __OGGZ_DLIST_H__
#define __OGGZ_DLIST_H__

struct _OggzDList;
typedef struct _OggzDList OggzDList;

typedef enum {DLIST_ITER_CANCEL, DLIST_ITER_CONTINUE} OggzDListIterResponse;

typedef OggzDListIterResponse (*OggzDListIterFunc) (void *elem);

OggzDList *
oggz_dlist_new (void);

void
oggz_dlist_delete(OggzDList *dlist);

int
oggz_dlist_is_empty(OggzDList *dlist);

void
oggz_dlist_append(OggzDList *dlist, void *elem);

void
oggz_dlist_prepend(OggzDList *dlist, void *elem);

void
oggz_dlist_iter(OggzDList *dlist, OggzDListIterFunc func);

void
oggz_dlist_reverse_iter(OggzDList *dlist, OggzDListIterFunc func);

void
oggz_dlist_deliter(OggzDList *dlist, OggzDListIterFunc func);

void
oggz_dlist_reverse_deliter(OggzDList *dlist, OggzDListIterFunc func);

#endif

==> liboggz_1.1.3.orig.tar.gz: liboggz-1.1.3/src/liboggz/oggz_dlist.h <==
/*
   Copyright (C) 2003 Commonwealth Scientific and Industrial Research
   Organisation (CSIRO) Australia

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   - Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

   - Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

   - Neither the name of CSIRO Australia nor the names of its
   contributors may be used to endorse or promote products derived from
   this software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
   PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE ORGANISATION OR
   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#ifndef OGGZ_DLIST_HEADER
#define OGGZ_DLIST_HEADER

struct OggzDList_;
typedef struct OggzDList_ OggzDList;

typedef enum {DLIST_ITER_ERROR=-1, DLIST_ITER_CANCEL=0, DLIST_ITER_CONTINUE=1} OggzDListIterResponse;

typedef OggzDListIterResponse (*OggzDListIterFunc) (void *elem);

OggzDList *
oggz_dlist_new (void);

void
oggz_dlist_delete(OggzDList *dlist);

int
oggz_dlist_is_empty(OggzDList *dlist);

int
oggz_dlist_append(OggzDList *dlist, void *elem);

int
oggz_dlist_prepend(OggzDList *dlist, void *elem);

int
oggz_dlist_iter(OggzDList *dlist, OggzDListIterFunc func);

void
oggz_dlist_reverse_iter(OggzDList *dlist, OggzDListIterFunc func);

int
oggz_dlist_deliter(OggzDList *dlist, OggzDListIterFunc func);

void
oggz_dlist_reverse_deliter(OggzDList *dlist, OggzDListIterFunc func);

#endif /* OGGZ_DLIST_HEADER */
